<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>ໄຟລ໌ທັງຫມົດ (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authenticating</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>ໂໝດຍົນ</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>ຢຸດການສື່ສານແບບໄຮ້ສາຍ</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>ການເປີດໃຊ້ໂໝດຍົນຈະປິດເຄືອຂ່າຍໄຮ້ສາຍ, ຮັອດສະປອດສ່ວນຕົວ ແລະ Bluetooth</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>ພຣອກຊີແອັບພລິເຄຊັນ</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>ຕັ້ງຄ່າເຊີເວີພຣອກຊີ</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ປະເພດພຣອກຊີ</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>ທີ່ຢູ່ IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ທີ່ຢູ່ IP ບໍ່ຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>ພອດ</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>ພອດບໍ່ຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ຊື່ຜູ້ໃຊ້</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>ທາງເລືອກ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>ລະຫັດຜ່ານ</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>ກວດສອບ &quot;ໃຊ້ພຣອກຊີ&quot; ໃນເມນູແອັບພລິເຄຊັນໃນ Launcher ຫຼັງຈາກຕັ້ງຄ່າແລ້ວ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ບັນທຶກ</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>ຕັ້ງຄ່າການເຊື່ອມຕໍ່ເຄືອຂ່າຍ dial-up</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>ຕັດການເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>ເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>ເພີ່ມການຕຳຕັ້ງ PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>ລົບ</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>ທ່ານຕ້ອງການລົບການຕຳຕັ້ງນີ້ຫຼືບໍ່?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ບັນທຶກ</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>ລາຍລະອຽດເຄືອຂ່າຍ</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>ດູການຕັ້ງຄ່າເຄືອຂ່າຍທັງຫມດ</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>ລາຍລະອຽດຖືກຄອບປີ້ແລ້ວ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ຄອບປີ້</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>ເລືອກທັງຫມດ</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>ການຕຣວຈສອບເຄືອຂ່າຍ</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 ສ່ວນບຸກຄົນ</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 ສ່ວນບຸກຄົນ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>ບໍ່ມີ</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ອັບເດດ</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>ບໍ່ຖືກຕຳມ</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>ຮັອດສະປອດສ່ວນຕົວ</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>ແບ່ງປັນເຄືອຂ່າຍ</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>ຮັອດສະປອດຂອງຂ້ອຍ</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>ແກ້ໄຂຮັອດສະປອດຂອງຂ້ອຍ</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>ຊື່ (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>ຄວາມປອດທັຍ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>ລະຫັດຜ່ານ</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>ຄື່ນຄວາມຖີ່</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ບັນທຶກ</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>ການຕັ້ງຄ່າແບ່ງປັນ</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>ອຸປະກອນແບ່ງປັນ Hotspot</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>ຫາກທ່ານຕ້ອງການໃຊ້ hotspot ສ່ວນຕົວ, ກະລຸນາປິດໂມດຄານບິນແລ້ວເປີດອັດເຕອ່ເຄືອຂ່າຍໄວ້ລີສໄດ່້ວຍ</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>ຫາກທ່ານຕ້ອງການໃຊ້ hotspot ສ່ວນຕົວ, ກະລຸນາປິດ&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;ໂມດຄານບິນ&lt;/a&gt;ແລ້ວເປີດອັດເຕອ່ເຄືອຂ່າຍໄວ້ລີສ</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>ລົບ</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>ທ່ານແນ່ໃຈว່າຕ້ອງການລົບການຕັ້ງຄ່ານີ້ຫລືບໍ່?
</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ບັນທຶກ</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>ພຣອກຊີລະບົບ</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>ຕັ້ງຄ່າເຊີເວີພຣອກຊີ</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ປະເພດພຣອກຊີ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ອັດຕະໂນມັດ</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ຕັ້ງຄ່າເອງ</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL ການຕັ້ງຄ່າ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>ພຣອກ຋ີ HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>ພຣອກ຋ີ HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>ພຣອກ຋ີ FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS ປະເພາະນຳເຂົ້າ</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>ອ່ານລົງການຕຳແໜ່ງປະເພາະຂອງ:host ແລະ domain ນີ້</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ເບິ່ງປົກກະຕິ</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>ເຊື່ອມຕໍ່, ເພີ່ມ, ນຳເຂົ້າ</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>ຕັດການເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>ເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>ເພີ່ມ VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>ນຳເຂົ້າ VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>ຄວາມຜິດພລາດໃນການນຳເຂົ້າ</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>ຄວາມຜິດພລາດໄຟລ້</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ຕົກລົງ</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>ປະເພາະVPN</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ລົບ</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>ຕ້ອງການລົບການຕຳແໜ່ງນີ້ບໍ່?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ສົ່ງອອກ</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ບັນທຶກ</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>ເຊື່ອມຕໍ່, ແກ້ໄຂການຕັ້ງຄ່າເຄືອຂ່າຍ</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>ສຽບສາຍເຄືອຂ່າຍກ່ອນ</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>ຕັດການເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>ເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>ເພີ່ມການເຊື່ອມຕໍ່ເຄືອຂ່າຍ</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>ເຊື່ອມຕໍ່, ແກ້ໄຂການຕັ້ງຄ່າເຄືອຂ່າຍ</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>ຕັດການເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>ເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>ເຄືອຂ່າຍອື່ນໆ</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>ປິດໂໝດຍົນກ່ອນຖ້າທ່ານຕ້ອງການເຊື່ອມຕໍ່ກັບເຄືອຂ່າຍໄຮ້ສາຍ</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>ປິດ &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;ໂໝດຍົນ&lt;/a&gt; ກ່ອນຖ້າທ່ານຕ້ອງການເຊື່ອມຕໍ່ກັບເຄືອຂ່າຍໄຮ້ສາຍ</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>ປິດຮັອດສະປອດກ່ອນຖ້າທ່ານຕ້ອງການເຊື່ອມຕໍ່ກັບເຄືອຂ່າຍໄຮ້ສາຍ</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;ປິດຮັອດສະປອດ&lt;/a&gt; ກ່ອນຖ້າທ່ານຕ້ອງການເຊື່ອມຕໍ່ກັບເຄືອຂ່າຍໄຮ້ສາຍ</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>ສຳເລັດ</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ແກ້ໄຂ</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ທີ່ຢູ່ IP ບໍ່ຖືກຕ້ອງ</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>ບໍ່ຜູກມັດ</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>ທີ່ຢູ່ MAC ອຸປະກອນ</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>ທີ່ຢູ່ MAC ທີ່ບັດກວນ</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>ກຳນົດ MTU ເອງ</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>ຄື່ນຄວາມຖີ່</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ອັດຕະໂນມັດ</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>ທັ່ວໄປ</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>ຊື່ (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>ຊື່</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>ເຊື່ອມຕໍ່ອັດຕະໂນມັດ</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>ເສັດສິ້ນ</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ແກ້ໄຂ</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>ປິດໃຊ້ງານ</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ຕັ້ງຄ່າເອງ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ອັດຕະໂນມັດ</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>ວິທີການ</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>ເທີ່ງໃຊ້ໃນຊັພພະຍາກອນທີ່ກ່ຽວຂ້ອງເທົ່ານັ້ນ</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>ທີ່ອยູ່ IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ທີ່ອນູ່ IP ບໍ່ອຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ນີດມາສ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ເກດເວຍໄ</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>ນີດມາສບໍ່ອຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>ເກດເວຍບໍ່ຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>ທີ່ຢູ່ IP ຊ້ຳກັນ</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>ປິດໃຊ້ງານ</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ແມນນວນ</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>ບໍ່ສົນໃຈ</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>ອັດຕະໂນມັດ</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>ສຳເລັດ</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ແກ້ໄຂ</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>ວິທີການ</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>ໃຊ້ຢູ່ໃນຊັບພະຍາກອນທີ່ສອດຄ່ອງເທົ່ານັ້ນ</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>ທີ່ຢູ່ IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>ທີ່ຢູ່ IP ບໍ່ຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>ຄຳນຳໜ້າ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ເກດເວຍ</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>ເນັດມາສບໍ່ຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>ທີ່ຢູ່ IP ຊ້ຳກັນ</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>ເກດເວຍບໍ່ຖືກຕ້ອງ</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>ໃຊ້ MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128-bit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Stateful</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>ບໍ່ມີການບີບອັດຂໍ້ມູນ BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>ບໍ່ມີການບີບອັດຂໍ້ມູນ Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>ບໍ່ມີການບີບອັດ TCP Header</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>ສົ່ງແພັກເກັດ PPP Echo</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ຊື່ຜູ້ໃຊ້</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>ບໍລິການ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>ລະຫັດຜ່ານ</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>ຄວາມປອດໄພ</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS ແບບອຸໂມງ</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP ທີ່ມີການປົກປ້ອງ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>ບໍ່ມີ</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 ສ່ວນບຸກຄົນ</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 ອົງກອນ</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 ສ່ວນບຸກຄົນ</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>ການພິສູດຕົວຕົນ EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>ຕົວຕົນ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>ຕົວເລືອກລະຫັດຜ່ານ</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>ບັນທຶກລະຫັດຜ່ານສຳລັບຜູ້ໃຊ້ນີ້</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>ບັນທຶກລະຫັດຜ່ານສຳລັບຜູ້ໃຊ້ທັງໝົດ</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>ຖາມຂ້ອຍຕະຫຼອດ</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>ກະແຈ</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>ລະຫັດຜ່ານສ່ວນຕົວ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>ລະຫັດຜ່ານ</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>ການພິສູດຕົວຕົນ</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>ກະແຈຮ່ວມ</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>ລະບົບເປີດ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>ກະແຈສ່ວນຕົວ</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID ບໍ່ປະກົດຊື່</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>ການເຕຍມການ</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>ປິດໃຊ້ງານ</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>ບໍ່ປະກົດຊື່</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>ພິສູດຕົວຕົນແລ້ວ</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>ທັງສອງ</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>ໄຟລ໌ PAC</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>ໃບຢັ້ງຢືນ CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ໃບຢັ້ງຢືນຜູ້ໃຊ້</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>ເວີຊັນ PEAP</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>ອັດຕະໂນມັດ</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>ເວີຊັນ 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>ເວີຊັນ 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>ການພິສູດຕົວຕົນພາຍໃນ</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>ໄຟລ໌ທັງຫມົດ (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ຈຳເປັນ</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>ເກດເວຍບໍ່ຖືກຕ້ອງ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ເກດເວຍ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>ໃບຢັ້ງຢືນ CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>ພຣັອກຊີ</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>ອະນຸຍາດ Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>ສະຄຣິບ CSD</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>ປະເພດການພິສູດຕົວຕົນ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>ກະແຈສ່ວນຕົວ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>ສະມາດກາດ</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>ກະແຈຮ່ວມກັນລ່ວງໜ້າ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ໃບຢັ້ງຢືນຜູ້ໃຊ້</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ຊື່ຜູ້ໃຊ້</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>ໃຊ້ FSID ສຳລັບລະຫັດຜ່ານກະແຈ</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>ໃບຢັ້ງຢືນ (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>ລະຫັດຜ່ານ</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>ໃບຢັ້ງຢືນທີ່ມີລະຫັດຜ່ານ (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>ກະແຈຄົງທີ່</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>ຕົວເລືອກລະຫັດຜ່ານ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ບັນທຶກແລ້ວ</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>ຖາມ</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>ບໍ່ຈຳເປັນ</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>ລະຫັດຜ່ານສ່ວນຕົວ</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>ກຳນົດທິດທາງກະແຈເອງ</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>ທິດທາງກະແຈ</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP ຫ່າງໄກ</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP ທ້ອງຖິ່ນ</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>ໂດເມນ NT</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>ຂໍທີ່ຢູ່ IP ພາຍໃນ</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>ບັງຄັບການຫໍ່ຫຸ້ມ UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>ໃຊ້ການບີບອັດ IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>ເປີດໃຊ້ການສະເໜີລະຫັດເອງ</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>ຊື່ກຸ່ມ</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>ລະຫັດຜ່ານກຸ່ມ</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>ໃຊ້ການພິສູດຕົວຕົນແບບຜະສົມ</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>ໄຟລ໌ CA</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>ໃຊ້ MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>ຄວາມປອດໄພ</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>ທັງຫມົດທີ່ມີ (ຄ່າເລີ່ມຕົ້ນ)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (ປອດໄພນ້ອຍກວ່າ)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (ປອດໄພທີ່ສຸດ)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Stateful</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>ປະຕິເສດການພິສູດຕົວຕົນ MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>ບໍ່ມີການບີບອັດຂໍ້ມູນ BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>ບໍ່ມີການບີບອັດຂໍ້ມູນ Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>ບໍ່ມີການບີບອັດ TCP Header</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>ບໍ່ມີການບີບອັດຟິວໂປຣໂຕຄໍ</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>ບໍ່ມີການບີບອັດທີ່ຢູ່/ການຄວບຄຸມ</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>ສົ່ງແພັກເກັດ PPP Echo</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>ເປີດໃຊ້ IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID ກຸ່ມ</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>ຂັ້ນຕອນ 1 ອັລກໍລິທຶມ</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>ຂັ້ນຕອນ 2 ອັລກໍລິທຶມ</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN ຂັ້ນສູງ</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>ກຳນົດພອດເກດເວຍເອງ</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>ພອດເກດເວຍ</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>ກຳນົດເວລາເຈລະຈາໃໝ່ເອງ</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>ເວລາເຈລະຈາໃໝ່</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>ໃຊ້ການບີບອັດຂໍ້ມູນ LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>ໃຊ້ການເຊື່ອມຕໍ່ TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>ໃຊ້ອຸປະກອນ TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>ກຳນົດ MTU ອຸໂມງເອງ</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>ກຳນົດຂະໜາດສ່ວນ UDP ເອງ</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>ຂະໜາດສ່ວນ UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>ຈຳກັດ TCP MSS ອຸໂມງ</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>ສຸ່ມໂຮສຫ່າງໄກ</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>ໂດເມນ</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>ຜູ້ຜະລິດ</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (ຄ່າເລີ່ມຕົ້ນ)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>ເວີຊັນ</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>ການເຂົ້າລະຫັດ</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>ປອດໄພ (ຄ່າເລີ່ມຕົ້ນ)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>ອ່ອນແອ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>ບໍ່ມີ</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>ໂໝດ NAT Traversal</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T ເມື່ອມີ (ຄ່າເລີ່ມຕົ້ນ)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T ຕະຫຼອດ</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>ປິດໃຊ້ງານ</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>ກຸ່ມ IKE DH</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>ກຸ່ມ DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>ກຸ່ມ DH 2 (ຄ່າເລີ່ມຕົ້ນ)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>ກຸ່ມ DH 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>ເຊີເວີ (ຄ່າເລີ່ມຕົ້ນ)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>ກຸ່ມ DH 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>ພອດທ້ອງຖິ່ນ</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>ປິດການກວດສອບ Dead Peer</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>ຄວາມປອດໄພ VPN</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>ລະຫັດເຂົ້າລະຫັດ</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>ຄ່າເລີ່ມຕົ້ນ</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server IP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subject Match</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>ປິດ &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;ໂໝດຍົນ&lt;/a&gt; ກ່ອນຖ້າທ່ານຕ້ອງການເຊື່ອມຕໍ່ກັບເຄືອຂ່າຍໄຮ້ສາຍ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>ຄວາມຂັດແຍ້ງ IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ເຄືອຂ່າຍ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>ການເຊື່ອມຕໍ່ລວງຈາກ %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>ການເຊື່ອມຕໍ່ PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>ການເຊື່ອມຕໍ່ &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; ເຊື່ອມຕໍ່ແລ້ວ</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; ຍົກເລີກເຊື່ອມຕໍ່ແລ້ວ</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>ບໍ່ສາມາດເຊື່ອມຕໍ່ &quot;%1&quot;, ກະລຸນາກວດສອບເຣາເຕີຫຼືສາຍເຄືອຂ່າຍຂອງທ່ານ</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>ບໍ່ສາມາດເຊື່ອມຕໍ່ &quot;%1&quot;, ກະລຸນາເຂົ້າໃກ້ເຣາເຕີໄຮ້ສາຍ</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>ການເຊື່ອມຕໍ່ລົ້ມເຫລວ, ບໍ່ສາມາດເຊື່ອມຕໍ່ &quot;%1&quot;, ລະຫັດຜ່ານຜິດ</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>ຈຳເປັນຕ້ອງມີລະຫັດຜ່ານເພື່ອເຊື່ອມຕໍ່ &quot;%1&quot;</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>ບໍ່ພົບເຄືອຂ່າຍ WLAN 802.11 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>ເພື່ອເຊື່ອມຕໍ່ &quot;%1&quot;, ກະລຸນາຕັ້ງຄ່າການພິສູດຕົວຕົນຫລັງຈາກການເຂົ້າລະບົບ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>ຕົວການຕົວຢ່າງຂອງລະບົບ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>ການຕັ້ງຄ່າ VPN ບໍ່ເຊື່ອມຕໍ່ແລ້ວຫລືການເຊື່ອມຕໍ່ລົດ. ກະລຸນາ &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;ໄປທີ່ຨູດຄວບຄຸມການຕັ້ງຄ່າ&lt;/a&gt; ສຳລັບການຕົວຢ່າງ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>ສະຖານະການເຊື່ອມຕໍ່ລາງ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>ສະຖານະການເຊື່ອມຕໍ່ລາງ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>ເຊື່ອມຕໍ່ໄປທີ່ສະຖານະການເຊື່ອມຕໍ່ລາງ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>ສະຖານະການເຊື່ອມຕໍ່ຂອງຂ້ອຍ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>ສະຖານະການເຊື່ອມຕໍ່ອື່ນ</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>ເຄືອຂ່າຍ</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>